@@ -10,17 +10,28 @@
 #' @param hprop default = 6.7; altezza dell'immagine, in proporzione ai ppi (es: 4)
 #' @param wprop default = 6.7; larghezza dell'immagine, in proporzione ai ppi (es: 4)
 #' @param ... altri argomenti ereditati \code{\link[grDevices]{dev.copy}}
-#' @examples expchart(png, file = "chart.png", ppi = 300, hprop = 4, wprop = 4)
+#' @examples
+#' \dontrun{
+#' expchart(png, file = "chart.png", ppi = 300, hprop = 4, wprop = 4)
+#' }
 #' @return file immagine
 #' @import grDevices
 #' @export
-expchart <- function(device = png, file, ppi = 72, hprop = 6.7, wprop = 6.7, ...)
-{
-  dev.copy(device,
-           file,
-           width = wprop*ppi,
-           height = hprop*ppi,
-           res = ppi,
-           ...)
+expchart <- function(
+  device = png,
+  file,
+  ppi = 72,
+  hprop = 6.7,
+  wprop = 6.7,
+  ...
+) {
+  dev.copy(
+    device,
+    file,
+    width = wprop * ppi,
+    height = hprop * ppi,
+    res = ppi,
+    ...
+  )
   dev.off()
 }
